import { useQuery } from "@tanstack/react-query";
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import ListingForm from "@/components/forms/ListingForm";
import { Redirect } from "wouter";

const CreateListing = () => {
  // Check if user is logged in
  const { data: userData, isLoading } = useQuery<{ user: any }>({
    queryKey: ['/api/auth/current-user'],
    retry: false,
  });

  // If the user is not logged in, redirect to login page
  if (!isLoading && !userData?.user) {
    return <Redirect to="/login" />;
  }

  return (
    <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 py-10">
      <Card>
        <CardHeader>
          <CardTitle className="text-center text-2xl">Déposer une annonce</CardTitle>
        </CardHeader>
        <CardContent>
          {isLoading ? (
            <div className="space-y-4">
              <div className="h-10 bg-gray-100 rounded animate-pulse"></div>
              <div className="h-10 bg-gray-100 rounded animate-pulse"></div>
              <div className="h-20 bg-gray-100 rounded animate-pulse"></div>
            </div>
          ) : (
            <ListingForm />
          )}
        </CardContent>
      </Card>
    </div>
  );
};

export default CreateListing;
